@@ -30,6 +30,7 @@ maybe_download <- function(url, root, name, extract_fun, download) {
   if (!fs::dir_exists(data_path) && download) {
     tmp <- tempfile()
     download_file(url, tmp)
+    fs::dir_create(fs::path_dir(data_path), recurse = TRUE)
     extract_fun(tmp, data_path)
   }
 
@@ -38,3 +39,11 @@ maybe_download <- function(url, root, name, extract_fun, download) {
 
   data_path
 }
+
+unzip2 <- function(path, exdir) {
+  if (grepl("linux", R.version$os)) {
+    utils::unzip(path, exdir = exdir)
+  } else {
+    zip::unzip(path, exdir = exdir)
+  }
+}
